A crash is the result of unexpected or unhandled behaviours. It might be the result of missing input validations, incorrect serializations, or unallowed operations etc.

An attacker may try to find the code path that leads to the faulty procedure and attempt to execute arbitrary code through potential vulnerabilities.

Crashes may give an attacker valuable information about the system and its internal details. Crashes may also create temporary vulnerabilities or leave unprotected files (e.g. memory dumps) that may be exploited.